@@ -13,32 +13,32 @@ impl Customers {
     }
 
     /**
-     * This function performs a `GET` to the `/admin/directory/v1/customers/{customerKey}` endpoint.
-     *
-     * Retrieves a customer.
-     *
-     * **Parameters:**
-     *
-     * * `customer_key: &str` -- Id of the customer to be retrieved.
-     */
+    * This function performs a `GET` to the `/admin/directory/v1/customers/{customerKey}` endpoint.
+    *
+    * Retrieves a customer.
+    *
+    * **Parameters:**
+    *
+    * * `customer_key: &str` -- Id of the customer to be retrieved.
+    */
     pub async fn get(&self, customer_key: &str) -> Result<crate::types::Customer> {
         let url = format!(
             "/admin/directory/v1/customers/{}",
-            crate::progenitor_support::encode_path(&customer_key.to_string()),
+            crate::progenitor_support::encode_path(customer_key),
         );
 
         self.client.get(&url, None).await
     }
 
     /**
-     * This function performs a `PUT` to the `/admin/directory/v1/customers/{customerKey}` endpoint.
-     *
-     * Updates a customer.
-     *
-     * **Parameters:**
-     *
-     * * `customer_key: &str` -- Id of the customer to be updated.
-     */
+    * This function performs a `PUT` to the `/admin/directory/v1/customers/{customerKey}` endpoint.
+    *
+    * Updates a customer.
+    *
+    * **Parameters:**
+    *
+    * * `customer_key: &str` -- Id of the customer to be updated.
+    */
     pub async fn update(
         &self,
         customer_key: &str,
@@ -46,7 +46,7 @@ impl Customers {
     ) -> Result<crate::types::Customer> {
         let url = format!(
             "/admin/directory/v1/customers/{}",
-            crate::progenitor_support::encode_path(&customer_key.to_string()),
+            crate::progenitor_support::encode_path(customer_key),
         );
 
         self.client
@@ -55,14 +55,14 @@ impl Customers {
     }
 
     /**
-     * This function performs a `PATCH` to the `/admin/directory/v1/customers/{customerKey}` endpoint.
-     *
-     * Patches a customer.
-     *
-     * **Parameters:**
-     *
-     * * `customer_key: &str` -- Id of the customer to be updated.
-     */
+    * This function performs a `PATCH` to the `/admin/directory/v1/customers/{customerKey}` endpoint.
+    *
+    * Patches a customer.
+    *
+    * **Parameters:**
+    *
+    * * `customer_key: &str` -- Id of the customer to be updated.
+    */
     pub async fn patch(
         &self,
         customer_key: &str,
@@ -70,7 +70,7 @@ impl Customers {
     ) -> Result<crate::types::Customer> {
         let url = format!(
             "/admin/directory/v1/customers/{}",
-            crate::progenitor_support::encode_path(&customer_key.to_string()),
+            crate::progenitor_support::encode_path(customer_key),
         );
 
         self.client
@@ -79,52 +79,52 @@ impl Customers {
     }
 
     /**
-     * This function performs a `GET` to the `/admin/directory/v1/{name}` endpoint.
-     *
-     * Returns a `Printer` resource (printer's config).
-     *
-     * **Parameters:**
-     *
-     * * `name: &str` -- Required. The name of the printer to retrieve. Format: customers/{customer_id}/chrome/printers/{printer_id}.
-     */
+    * This function performs a `GET` to the `/admin/directory/v1/{name}` endpoint.
+    *
+    * Returns a `Printer` resource (printer's config).
+    *
+    * **Parameters:**
+    *
+    * * `name: &str` -- Required. The name of the printer to retrieve. Format: customers/{customer_id}/chrome/printers/{printer_id}.
+    */
     pub async fn admin_chrome_printers_get(&self, name: &str) -> Result<crate::types::Printer> {
         let url = format!(
             "/admin/directory/v1/{}",
-            crate::progenitor_support::encode_path(&name.to_string()),
+            crate::progenitor_support::encode_path(name),
         );
 
         self.client.get(&url, None).await
     }
 
     /**
-     * This function performs a `DELETE` to the `/admin/directory/v1/{name}` endpoint.
-     *
-     * Deletes a `Printer`.
-     *
-     * **Parameters:**
-     *
-     * * `name: &str` -- Required. The name of the printer to be updated. Format: customers/{customer_id}/chrome/printers/{printer_id}.
-     */
+    * This function performs a `DELETE` to the `/admin/directory/v1/{name}` endpoint.
+    *
+    * Deletes a `Printer`.
+    *
+    * **Parameters:**
+    *
+    * * `name: &str` -- Required. The name of the printer to be updated. Format: customers/{customer_id}/chrome/printers/{printer_id}.
+    */
     pub async fn admin_chrome_printers_delete(&self, name: &str) -> Result<crate::types::Empty> {
         let url = format!(
             "/admin/directory/v1/{}",
-            crate::progenitor_support::encode_path(&name.to_string()),
+            crate::progenitor_support::encode_path(name),
         );
 
         self.client.delete(&url, None).await
     }
 
     /**
-     * This function performs a `PATCH` to the `/admin/directory/v1/{name}` endpoint.
-     *
-     * Updates a `Printer` resource.
-     *
-     * **Parameters:**
-     *
-     * * `name: &str` -- The resource name of the Printer object, in the format customers/{customer-id}/printers/{printer-id} (During printer creation leave empty).
-     * * `clear_mask: &str` -- The list of fields to be cleared. Note, some of the fields are read only and cannot be updated. Values for not specified fields will be patched.
-     * * `update_mask: &str` -- The list of fields to be updated. Note, some of the fields are read only and cannot be updated. Values for not specified fields will be patched.
-     */
+    * This function performs a `PATCH` to the `/admin/directory/v1/{name}` endpoint.
+    *
+    * Updates a `Printer` resource.
+    *
+    * **Parameters:**
+    *
+    * * `name: &str` -- The resource name of the Printer object, in the format customers/{customer-id}/printers/{printer-id} (During printer creation leave empty).
+    * * `clear_mask: &str` -- The list of fields to be cleared. Note, some of the fields are read only and cannot be updated. Values for not specified fields will be patched.
+    * * `update_mask: &str` -- The list of fields to be updated. Note, some of the fields are read only and cannot be updated. Values for not specified fields will be patched.
+    */
     pub async fn admin_chrome_printers_patch(
         &self,
         name: &str,
@@ -142,7 +142,7 @@ impl Customers {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/admin/directory/v1/{}?{}",
-            crate::progenitor_support::encode_path(&name.to_string()),
+            crate::progenitor_support::encode_path(name),
             query_
         );
 
@@ -152,18 +152,18 @@ impl Customers {
     }
 
     /**
-     * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers` endpoint.
-     *
-     * List printers configs.
-     *
-     * **Parameters:**
-     *
-     * * `parent: &str` -- Required. The name of the customer who owns this collection of printers. Format: customers/{customer_id}.
-     * * `filter: &str` -- Search query. Search syntax is shared between this api and Admin Console printers pages.
-     * * `org_unit_id: &str` -- Organization Unit that we want to list the printers for. When org_unit is not present in the request then all printers of the customer are returned (or filtered). When org_unit is present in the request then only printers available to this OU will be returned (owned or inherited). You may see if printer is owned or inherited for this OU by looking at Printer.org_unit_id.
-     * * `page_size: i64` -- The maximum number of objects to return. The service may return fewer than this value.
-     * * `page_token: &str` -- A page token, received from a previous call.
-     */
+    * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers` endpoint.
+    *
+    * List printers configs.
+    *
+    * **Parameters:**
+    *
+    * * `parent: &str` -- Required. The name of the customer who owns this collection of printers. Format: customers/{customer_id}.
+    * * `filter: &str` -- Search query. Search syntax is shared between this api and Admin Console printers pages.
+    * * `org_unit_id: &str` -- Organization Unit that we want to list the printers for. When org_unit is not present in the request then all printers of the customer are returned (or filtered). When org_unit is present in the request then only printers available to this OU will be returned (owned or inherited). You may see if printer is owned or inherited for this OU by looking at Printer.org_unit_id.
+    * * `page_size: i64` -- The maximum number of objects to return. The service may return fewer than this value.
+    * * `page_token: &str` -- A page token, received from a previous call.
+    */
     pub async fn admin_chrome_printers_list(
         &self,
         parent: &str,
@@ -188,7 +188,7 @@ impl Customers {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers?{}",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
             query_
         );
 
@@ -199,12 +199,12 @@ impl Customers {
     }
 
     /**
-     * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers` endpoint.
-     *
-     * As opposed to `admin_chrome_printers_list`, this function returns all the pages of the request at once.
-     *
-     * List printers configs.
-     */
+    * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers` endpoint.
+    *
+    * As opposed to `admin_chrome_printers_list`, this function returns all the pages of the request at once.
+    *
+    * List printers configs.
+    */
     pub async fn admin_chrome_printers_list_all(
         &self,
         parent: &str,
@@ -221,7 +221,7 @@ impl Customers {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers?{}",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
             query_
         );
 
@@ -258,14 +258,14 @@ impl Customers {
     }
 
     /**
-     * This function performs a `POST` to the `/admin/directory/v1/{parent}/chrome/printers` endpoint.
-     *
-     * Creates a printer under given Organization Unit.
-     *
-     * **Parameters:**
-     *
-     * * `parent: &str` -- Required. The name of the customer. Format: customers/{customer_id}.
-     */
+    * This function performs a `POST` to the `/admin/directory/v1/{parent}/chrome/printers` endpoint.
+    *
+    * Creates a printer under given Organization Unit.
+    *
+    * **Parameters:**
+    *
+    * * `parent: &str` -- Required. The name of the customer. Format: customers/{customer_id}.
+    */
     pub async fn admin_chrome_printers_create(
         &self,
         parent: &str,
@@ -273,7 +273,7 @@ impl Customers {
     ) -> Result<crate::types::Printer> {
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
         );
 
         self.client
@@ -282,14 +282,14 @@ impl Customers {
     }
 
     /**
-     * This function performs a `POST` to the `/admin/directory/v1/{parent}/chrome/printers:batchCreatePrinters` endpoint.
-     *
-     * Creates printers under given Organization Unit.
-     *
-     * **Parameters:**
-     *
-     * * `parent: &str` -- Required. The name of the customer. Format: customers/{customer_id}.
-     */
+    * This function performs a `POST` to the `/admin/directory/v1/{parent}/chrome/printers:batchCreatePrinters` endpoint.
+    *
+    * Creates printers under given Organization Unit.
+    *
+    * **Parameters:**
+    *
+    * * `parent: &str` -- Required. The name of the customer. Format: customers/{customer_id}.
+    */
     pub async fn admin_chrome_printers_batch_create(
         &self,
         parent: &str,
@@ -297,7 +297,7 @@ impl Customers {
     ) -> Result<crate::types::BatchCreatePrintersResponse> {
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers:batchCreatePrinters",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
         );
 
         self.client
@@ -306,14 +306,14 @@ impl Customers {
     }
 
     /**
-     * This function performs a `POST` to the `/admin/directory/v1/{parent}/chrome/printers:batchDeletePrinters` endpoint.
-     *
-     * Deletes printers in batch.
-     *
-     * **Parameters:**
-     *
-     * * `parent: &str` -- Required. The name of the customer. Format: customers/{customer_id}.
-     */
+    * This function performs a `POST` to the `/admin/directory/v1/{parent}/chrome/printers:batchDeletePrinters` endpoint.
+    *
+    * Deletes printers in batch.
+    *
+    * **Parameters:**
+    *
+    * * `parent: &str` -- Required. The name of the customer. Format: customers/{customer_id}.
+    */
     pub async fn admin_chrome_printers_batch_delete(
         &self,
         parent: &str,
@@ -321,7 +321,7 @@ impl Customers {
     ) -> Result<crate::types::BatchDeletePrintersResponse> {
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers:batchDeletePrinters",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
         );
 
         self.client
@@ -330,17 +330,17 @@ impl Customers {
     }
 
     /**
-     * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers:listPrinterModels` endpoint.
-     *
-     * Lists the supported printer models.
-     *
-     * **Parameters:**
-     *
-     * * `parent: &str` -- Required. The name of the customer who owns this collection of printers. Format: customers/{customer_id}.
-     * * `filter: &str` -- Filer to list only models by a given manufacturer in format: "manufacturer:Brother". Search syntax is shared between this api and Admin Console printers pages.
-     * * `page_size: i64` -- The maximum number of objects to return. The service may return fewer than this value.
-     * * `page_token: &str` -- A page token, received from a previous call.
-     */
+    * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers:listPrinterModels` endpoint.
+    *
+    * Lists the supported printer models.
+    *
+    * **Parameters:**
+    *
+    * * `parent: &str` -- Required. The name of the customer who owns this collection of printers. Format: customers/{customer_id}.
+    * * `filter: &str` -- Filer to list only models by a given manufacturer in format: "manufacturer:Brother". Search syntax is shared between this api and Admin Console printers pages.
+    * * `page_size: i64` -- The maximum number of objects to return. The service may return fewer than this value.
+    * * `page_token: &str` -- A page token, received from a previous call.
+    */
     pub async fn admin_chrome_printers_list_printer_models(
         &self,
         parent: &str,
@@ -361,7 +361,7 @@ impl Customers {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers:listPrinterModels?{}",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
             query_
         );
 
@@ -372,12 +372,12 @@ impl Customers {
     }
 
     /**
-     * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers:listPrinterModels` endpoint.
-     *
-     * As opposed to `admin_chrome_printers_list_printer_models`, this function returns all the pages of the request at once.
-     *
-     * Lists the supported printer models.
-     */
+    * This function performs a `GET` to the `/admin/directory/v1/{parent}/chrome/printers:listPrinterModels` endpoint.
+    *
+    * As opposed to `admin_chrome_printers_list_printer_models`, this function returns all the pages of the request at once.
+    *
+    * Lists the supported printer models.
+    */
     pub async fn admin_chrome_printers_list_all_printer_models(
         &self,
         parent: &str,
@@ -390,7 +390,7 @@ impl Customers {
         let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/admin/directory/v1/{}/chrome/printers:listPrinterModels?{}",
-            crate::progenitor_support::encode_path(&parent.to_string()),
+            crate::progenitor_support::encode_path(parent),
             query_
         );
 
